[![](https://img.shields.io/badge/GitHub-Paveloom/C3.1-5DA399.svg)](https://github.com/Paveloom/C3.1) [![](https://img.shields.io/badge/license-Unlicense-5DA399.svg)](https://github.com/Paveloom/C3/blob/master/LICENSE.md) <br>
[![](https://img.shields.io/badge/release-v0.2.1-informational.svg)](https://github.com/Paveloom/C3.1/releases/tag/v0.2.1) [![](https://img.shields.io/badge/platforms-linux,%20macOS-3E6680.svg)](#) [![](https://img.shields.io/badge/requires-python%203.7%2B-critical.svg)](https://www.python.org/downloads/)